==> react-lite-coder-0.0.1.tgz: package/lib/code-editor.js <==
(function() {
  var CodeMirror, React, T, _, cx, div, textarea;

  _ = require('lodash');

  cx = require('classnames');

  CodeMirror = require('codemirror');

  React = require('react');

  T = React.PropTypes;

  div = React.createFactory('div');

  textarea = React.createFactory('textarea');

  module.exports = React.createClass({
    displayName: 'lite-code-editor',
    propTypes: {
      readOnly: T.bool,
      option: T.object,
      defaultValue: T.string,
      mode: T.string,
      name: T.string,
      theme: T.string,
      onChange: T.func.isRequired
    },
    getDefaultProps: function() {
      return {
        mode: 'null',
        readOnly: false,
        theme: 'default'
      };
    },
    componentDidMount: function() {
      var defaultOption, editor, option;
      defaultOption = {
        indentUnit: 2,
        indentWithTabs: true,
        lineNumbers: true,
        lineWrapping: false,
        placeholder: 'Code goes here...',
        smartIndent: true,
        tabSize: 2
      };
      editor = this.refs.editor.getDOMNode();
      option = _.assign({}, defaultOption, this.props.option, {
        mode: this.props.mode,
        readOnly: this.props.readOnly,
        theme: this.props.theme
      });
      this.editor = CodeMirror.fromTextArea(editor, option);
      return this.editor.on('change', this.onEditorChange);
    },
    componentWillReceiveProps: function(nextProps) {
      if (this.editor.getOption('mode') !== nextProps.mode) {
        return this.editor.setOption('mode', nextProps.mode);
      }
    },
    onEditorChange: function() {
      var value;
      value = this.editor.getValue();
      return this.props.onChange(value);
    },
    renderEditor: function() {
      return textarea({
        className: 'editor',
        ref: 'editor',
        readOnly: this.props.readOnly,
        defaultValue: this.props.defaultValue,
        placeholder: this.props.placeholder,
        onChange: this.props.onChange
      });
    },
    render: function() {
      var className, obj;
      className = cx('lite-code-editor', (
        obj = {},
        obj["is-for-" + this.props.name] = this.props.name != null,
        obj
      ));
      return div({
        className: className
      }, this.renderEditor());
    }
  });

}).call(this);

==> react-lite-coder-0.0.2.tgz: package/lib/code-editor.js <==
(function() {
  var CodeMirror, React, T, cx, div, textarea;

  cx = require('classnames');

  React = require('react');

  CodeMirror = require('codemirror');

  require('codemirror/addon/display/placeholder');

  div = React.createFactory('div');

  textarea = React.createFactory('textarea');

  T = React.PropTypes;

  module.exports = React.createClass({
    displayName: 'lite-code-editor',
    propTypes: {
      onChange: T.func.isRequired,
      codeType: T.string,
      name: T.string,
      placeholder: T.string,
      text: T.string
    },
    getDefaultProps: function() {
      return {
        codeType: 'null',
        placeholder: 'Code goes here...',
        readOnly: false,
        text: ''
      };
    },
    componentDidMount: function() {
      var editor;
      this.option = {
        indentUnit: 2,
        indentWithTabs: false,
        lineNumbers: true,
        lineWrapping: false,
        mode: this.props.codeType,
        placeholder: this.props.placeholder,
        readOnly: this.props.readOnly,
        smartIndent: true,
        tabMode: 'spaces',
        tabSize: 2,
        theme: 'default',
        extraKeys: {
          'Tab': function(cm) {
            return cm.replaceSelection('  ', 'end');
          }
        }
      };
      editor = this.refs.editor.getDOMNode();
      this.editor = CodeMirror.fromTextArea(editor, this.option);
      return this.editor.on('change', this.onEditorChange);
    },
    componentWillReceiveProps: function(nextProps) {
      if (this.editor.getOption('mode' !== nextProps.codeType)) {
        return this.editor.setOption('mode', nextProps.codeType);
      }
    },
    onEditorChange: function() {
      var value;
      value = this.editor.getValue();
      return this.props.onChange(value);
    },
    renderEditor: function() {
      return textarea({
        className: 'editor',
        defaultValue: this.props.text,
        readOnly: this.props.readOnly,
        ref: 'editor',
        onChange: this.props.onChange
      });
    },
    render: function() {
      var className, obj;
      className = cx((
        obj = {
          'lite-code-editor': true
        },
        obj["is-for-" + this.props.name] = this.props.name != null,
        obj
      ));
      return div({
        className: className
      }, this.renderEditor());
    }
  });

}).call(this);
